@@ -1,9 +1,9 @@
 # broom::glance -----------------------------------------------------------
 
-#' Return one row summary data frame for a fitted model.
+#' @title Return one row summary data frame for a fitted model.
 #'
-#' \code{stat_fit_glance} fits a model and returns a summary "glance" of the
-#' model's statistics, using package 'broom'.
+#' @description \code{stat_fit_glance} fits a model and returns a summary
+#'   "glance" of the model's statistics, using package 'broom'.
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
 #'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_string}}. Only needs
@@ -23,18 +23,19 @@
 #' @param ... other arguments passed on to \code{\link[ggplot2]{layer}}. This
 #'   can include aesthetics whose values you want to set, not map. See
 #'   \code{\link[ggplot2]{layer}} for more details.
-#' @param na.rm	a logical indicating whether NA values should be stripped
-#'   before the computation proceeds.
+#' @param na.rm	a logical indicating whether NA values should be stripped before
+#'   the computation proceeds.
 #' @param method character.
 #' @param method.args list of arguments to pass to \code{method}.
 #' @param label.x.npc,label.y.npc \code{numeric} with range 0..1 or character.
 #'   Coordinates to be used for positioning the output, expressed in "normalized
-#'   parent coordinates" or character string. If too short they will be recycled.
+#'   parent coordinates" or character string. If too short they will be
+#'   recycled.
 #' @param label.x,label.y \code{numeric} Coordinates (in data units) to be used
 #'   for absolute positioning of the output. If too short they will be recycled.
 #'
-#' @section Computed variables:
-#'   The output of \code{\link[broom]{glance}} is returned as is.
+#' @section Computed variables: The output of \code{\link[broom]{glance}} is
+#'   returned as is in the \code{data} object.
 #'
 #' @export
 #'
@@ -77,6 +78,7 @@ fit_glance_compute_group_fun <- function(data,
                                          label.x,
                                          label.y) {
   force(data)
+
   if (length(unique(data$x)) < 2) {
     # Not enough data to perform fit
     return(data.frame())
@@ -109,7 +111,6 @@ fit_glance_compute_group_fun <- function(data,
   if (is.character(method)) method <- match.fun(method)
   mf <- do.call(method, method.args)
   z <- broom::glance(mf)
-#  print(z)
 
   if (length(label.x) > 0) {
     z$x <- label.x
@@ -187,10 +188,10 @@ StatFitGlance <-
 
 # broom::augment ----------------------------------------------------------
 
-#' Return the data augmented with fitted values and statistics.
+#' @title Return the data augmented with fitted values and statistics.
 #'
-#' \code{stat_fit_augment} fits a model and returns the data augmented with
-#' information from the fitted model, using package 'broom'.
+#' @description \code{stat_fit_augment} fits a model and returns the data
+#'   augmented with information from the fitted model, using package 'broom'.
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
 #'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_string}}. Only needs
@@ -210,26 +211,25 @@ StatFitGlance <-
 #' @param ... other arguments passed on to \code{\link[ggplot2]{layer}}. This
 #'   can include aesthetics whose values you want to set, not map. See
 #'   \code{\link[ggplot2]{layer}} for more details.
-#' @param na.rm	logical indicating whether NA values should be stripped
-#'   before the computation proceeds.
+#' @param na.rm	logical indicating whether NA values should be stripped before
+#'   the computation proceeds.
 #' @param method character.
 #' @param method.args list of arguments to pass to \code{method}.
 #' @param augment.args list of arguments to pass to \code{broom:augment}.
 #' @param level numeric Level of confidence interval to use (0.95 by default)
 #' @param y.out character (or numeric) index to column to return as \code{y}.
 #'
-#' @section Computed variables:
-#'   The output of \code{\link[broom]{augment}} is returned as is, except for
-#'   \code{y} which is set based on \code{y.out} and \code{y.observed} which
-#'   preserves the \code{y} returned by the \code{broom::augment} methods.
+#' @section Computed variables: The output of \code{\link[broom]{augment}} is
+#'   returned as is, except for \code{y} which is set based on \code{y.out} and
+#'   \code{y.observed} which preserves the \code{y} returned by the
+#'   \code{broom::augment} methods. This renaming is needed so that the geom
+#'   works as expected.
 #'
-#' @note The statistics \code{stat_fit_augment} and
-#'   \code{stat_fit_augment_panel} at the moment accepts only \code{methods}
-#'   that accept formulas under any formal parameter name and a \code{data}
-#'   argument. Use \code{ggplot2::stat_smooth()} instead of
-#'   \code{stat_fit_augment} in production code if the additional features are
-#'   not needed. At the moment \code{stat_fit_augment} is under development and
-#'   may change.
+#' @note The statistics \code{stat_fit_augment} accepts only \code{methods} that
+#'   accept formulas under any formal parameter name and a \code{data} argument.
+#'   Use \code{ggplot2::stat_smooth()} instead of \code{stat_fit_augment} in
+#'   production code if the additional features are not needed. At the moment
+#'   \code{stat_fit_augment} is under development and may change.
 #'
 #' @export
 #'
@@ -255,32 +255,6 @@ stat_fit_augment <- function(mapping = NULL, data = NULL, geom = "smooth",
   )
 }
 
-# #' @rdname stat_fit_augment
-# #'
-# #' @export
-# #'
-# stat_panel_fit_augment <- function(mapping = NULL, data = NULL, geom = "smooth",
-#                                    method = "lm",
-#                                    method.args = list(formula = y ~ x),
-#                                    augment.args = list(),
-#                                    level = 0.95,
-#                                    y.out = ".fitted",
-#                                    position = "identity",
-#                                    na.rm = FALSE, show.legend = FALSE,
-#                                    inherit.aes = TRUE, ...) {
-#   ggplot2::layer(
-#     stat = StatPanelFitAugment, data = data, mapping = mapping, geom = geom,
-#     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-#     params = list(method = method,
-#                   method.args = method.args,
-#                   augment.args = augment.args,
-#                   level = level,
-#                   y.out = y.out,
-#                   na.rm = na.rm,
-#                   ...)
-#   )
-# }
-
 # Defined here to avoid a note in check --as-cran as the imports from 'broom'
 # are not seen when the function is defined in-line in the ggproto object.
 #' @rdname ggpmisc-ggproto
@@ -309,15 +283,11 @@ fit_augment_compute_group_fun <- function(data,
     return(data.frame())
   }
   data <- data[order(data[["x"]]), ]
-#  print(tibble::as_data_frame(data))
   method.args <- c(method.args, list(data = quote(data)))
   if (is.character(method)) method <- match.fun(method)
   mf <- do.call(method, method.args)
-#  print(mf)
   augment.args <- c(list(x = mf), augment.args)
-#  print(augment.args)
   z <- do.call(broom::augment, augment.args)
-#  print(tibble::as_data_frame(z))
   z <- plyr::colwise(unAsIs)(z)
   tibble::as_data_frame(z)
   z[["y.observed"]] <- z[["y"]]
@@ -330,17 +300,9 @@ fit_augment_compute_group_fun <- function(data,
   if (!exists(".se.fit", z)) {
     z[[".se.fit"]] <- NA_real_
   }
-#  print(tibble::as_data_frame(z))
   z
 }
 
-# #' @rdname ggpmisc-ggproto
-# #'
-# #' @format NULL
-# #' @usage NULL
-# #'
-# fit_augment_compute_panel_fun <- fit_augment_compute_group_fun
-
 #' @rdname ggpmisc-ggproto
 #' @format NULL
 #' @usage NULL
@@ -355,27 +317,12 @@ StatFitAugment <-
                    required_aes = c("x", "y")
 )
 
-# #' @rdname ggpmisc-ggproto
-# #' @format NULL
-# #' @usage NULL
-# #' @export
-# StatPanelFitAugment <-
-#   ggplot2::ggproto("StatPanelFitAugment",
-#                    ggplot2::Stat,
-#                    compute_panel = fit_augment_compute_panel_fun,
-#                    default_aes =
-#                      ggplot2::aes(ymax = ..y.. + ...se.fit.. * ..t.value..,
-#                                   ymin = ..y.. - ...se.fit.. * ..t.value..),
-#                    required_aes = c("x", "y")
-#   )
-
-
 # broom::tidy -------------------------------------------------------------
 
-#' Return one row data frame with fitted parameter estimates.
+#' @title Return one row data frame with fitted parameter estimates.
 #'
-#' \code{stat_fit_tidy} fits a model and returns a "tidy" version of the
-#' model's summary, using package 'broom'.
+#' @description \code{stat_fit_tidy} fits a model and returns a "tidy" version
+#'   of the model's summary, using package 'broom'.
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
 #'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_string}}. Only needs
@@ -405,9 +352,10 @@ StatFitAugment <-
 #' @param label.x,label.y \code{numeric} Coordinates (in data units) to be used
 #'   for absolute positioning of the output. If too short they will be recycled.
 #'
-#' @section Computed variables:
-#'   The output of \code{\link[broom]{tidy}} is returned after reshaping it
-#'   into a single row.
+#' @section Computed variables: The output of \code{\link[broom]{tidy}} is
+#'   returned after reshaping it into a single row. Grouping is respected, and
+#'   the model fit separatately to each group of data. The returned \code{data}
+#'   object has one row for each group within a panel.
 #'
 #' @export
 #'
@@ -487,7 +435,16 @@ fit_tidy_compute_group_fun <- function(data,
   names(z.estimate) <- clean.term.names
   names(z.std.error) <- paste(clean.term.names, "se", sep = "_")
   z <- cbind(z.estimate, z.std.error)
- # print(z) # DEBUG
+  if (exists("statistic", mf.td, inherits = FALSE)) {
+    z.statistic <- as.data.frame(t(mf.td[["statistic"]]))
+    names(z.statistic) <- paste(clean.term.names, "stat", sep = "_")
+    z <- cbind(z, z.statistic)
+  }
+  if (exists("p.value", mf.td, inherits = FALSE)) {
+    z.p.value <- as.data.frame(t(mf.td[["p.value"]]))
+    names(z.p.value) <- paste(clean.term.names, "p.value", sep = "_")
+    z <- cbind(z, z.p.value)
+  }
 
   if (length(label.x) > 0) {
     z$x <- label.x
